@@ -8,7 +8,9 @@ use vars '@EXPORT_OK';
 use Dancer::Template;
 use Dancer::ModuleLoader;
 use Dancer::FileUtils 'path';
-use Carp 'confess';
+use Carp;
+
+use Encode;
 
 @EXPORT_OK = qw(setting mime_types);
 
@@ -73,8 +75,17 @@ my $setters = {
 my $normalizers = {
     charset => sub {
         my ($setting, $charset) = @_;
-        $charset = 'UTF-8' if $charset =~ /utf8/i;
-        return $charset;
+        length($charset || '')
+          or return $charset;
+        my $encoding = Encode::find_encoding($charset);
+        defined $encoding
+          or croak "Charset defined in configuration is wrong : couldn't identify '$charset'";
+        my $name = $encoding->name;
+        # Perl makes a distinction between the usual perl utf8, and the strict
+        # utf8 charset. But we don't want to make this distinction
+        $name eq 'utf-8-strict'
+          and $name = 'utf-8';
+        return $name;
     },
 };
 
@@ -271,9 +282,26 @@ Default value is 'text/html'.
 
 =head2 charset (string)
 
-The default charset of outgoing content. Unicode bodies in HTTP
-responses of C<text/*> types will be encoded to this charset. Also,
-C<charset=> item will be added to Content-Type response header.
+This setting does 3 things:
+
+=over
+
+=item *
+
+It sets the default charset of outgoing content. C<charset=> item will be
+added to Content-Type response header.
+
+=item *
+
+It makes Unicode bodies in HTTP responses of C<text/*> types to be encoded to
+this charset.
+
+=item *
+
+It also indicates to Dancer in which charset the static files and templates are
+encoded.
+
+=back
 
 Default value is empty which means don't do anything. HTTP responses
 without charset will be interpreted as ISO-8859-1 by most clients.
