@@ -26,7 +26,7 @@ sub send_file {
         code    => 404,
         message => "No such file: `$path'"
     );
-    Dancer::Response::set($error->render);
+    Dancer::Response->set($error->render);
 }
 
 sub template {
@@ -64,7 +64,7 @@ sub template {
                 code    => 404,
                 message => "Page not found",
             );
-            return Dancer::Response::set($error->render);
+            return Dancer::Response->set($error->render);
         }
 
         $_->($tokens) for (@{$app->registry->hooks->{before_template}});
@@ -82,7 +82,7 @@ sub template {
                 code    => 404,
                 message => "Page not found",
             );
-            return Dancer::Response::set($error->render);
+            return Dancer::Response->set($error->render);
         }
     }
 
@@ -102,7 +102,7 @@ sub error {
     my ($class, $content, $status) = @_;
     $status ||= 500;
     my $error = Dancer::Error->new(code => $status, message => $content);
-    Dancer::Response::set($error->render);
+    Dancer::Response->set($error->render);
 }
 
 sub redirect {
@@ -113,8 +113,8 @@ sub redirect {
         my $request = Dancer::SharedData->request;
         $destination = $request->uri_for($destination, {}, 1);
     }
-    Dancer::Response::status($status || 302);
-    Dancer::Response::headers('Location' => $destination);
+    Dancer::Response->status($status || 302);
+    Dancer::Response->headers('Location' => $destination);
 }
 
 #
