@@ -2,6 +2,7 @@ package Dancer::Route;
 
 use strict;
 use warnings;
+use Carp;
 use base 'Dancer::Object';
 
 use Dancer::App;
@@ -34,7 +35,7 @@ sub init {
     $self->{'_compiled_regexp'} = undef;
 
     if (!$self->pattern) {
-        die "cannot create Dancer::Route without a pattern";
+        croak "cannot create Dancer::Route without a pattern";
     }
 
     $self->check_options();
@@ -92,6 +93,14 @@ sub match {
 
     return unless @values;
 
+    # save the route pattern that matched
+    # TODO : as soon as we have proper Dancer::Internal, we should remove 
+    # that, it's just a quick hack for plugins to access the matching 
+    # pattern.
+    # NOTE: YOU SHOULD NOT USE THAT, OR IF YOU DO, YOU MUST KNOW
+    # IT WILL MOVE VERY SOON
+    $request->{_route_pattern} = $self->pattern;
+
     # named tokens
     my @tokens = @{$self->{_params} || []};
 
@@ -120,7 +129,7 @@ sub check_options {
     return 1 unless defined $self->options;
 
     for my $opt (keys %{$self->options}) {
-        die "Not a valid option for route matching: `$opt'"
+        croak "Not a valid option for route matching: `$opt'"
           if not(    (grep {/^$opt$/} @{$_supported_options[0]})
                   || (grep {/^$opt$/} keys(%_options_aliases)));
     }
@@ -144,14 +153,13 @@ sub run {
     my $content  = $self->execute();
     my $response = Dancer::Response->current;
 
-    if ($response->{pass}) {
-
+    if ($response->has_passed) {
         if ($self->next) {
             my $next_route = $self->find_next_matching_route($request);
             return $next_route->run($request);
         }
         else {
-            die "Last matching route passed";
+            croak "Last matching route passed";
         }
     }
 
@@ -163,10 +171,10 @@ sub run {
     $content = '' if $request->is_head;
 
     # init response headers
-    my $ct = $response->{content_type} || setting('content_type');
-    my $st = $response->{status}       || 200;
+    my $ct = $response->content_type() || setting('content_type');
+    my $st = $response->status()       || 200;
     my $headers = [];
-    push @$headers, @{$response->{headers}};
+    push @$headers, @{$response->headers_to_array};
 
     # content type may have already be set earlier
     # (eg: with send_error)
@@ -178,7 +186,6 @@ sub run {
         status       => $st,
         headers      => $headers,
         content      => $content,
-        content_type => $ct,
     );
 }
 
