@@ -2,18 +2,20 @@ package Dancer::Session::YAML;
 
 use strict;
 use warnings;
+use Carp;
 use base 'Dancer::Session::Abstract';
 
+use Dancer::Logger;
 use Dancer::ModuleLoader;
 use Dancer::Config 'setting';
-use Dancer::FileUtils 'path';
+use Dancer::FileUtils qw(path open_file);
 
 # static
 
 sub init {
     my ($class) = @_;
 
-    die "YAML is needed and is not installed"
+    croak "YAML is needed and is not installed"
       unless Dancer::ModuleLoader->load('YAML');
 
     # default value for session_dir
@@ -24,9 +26,9 @@ sub init {
     my $session_dir = setting('session_dir');
     if (!-d $session_dir) {
         mkdir $session_dir
-          or die "session_dir $session_dir cannot be created";
+          or croak "session_dir $session_dir cannot be created";
     }
-    Dancer::Logger->debug("session_dir : $session_dir");
+    Dancer::Logger::core("session_dir : $session_dir");
 }
 
 # create a new session and return the newborn object
@@ -57,13 +59,14 @@ sub yaml_file {
 sub destroy {
     my ($self) = @_;
     use Dancer::Logger;
-    Dancer::Logger::core("trying to remove session file: ".yaml_file($self->id));
+    Dancer::Logger::core(
+        "trying to remove session file: " . yaml_file($self->id));
     unlink yaml_file($self->id) if -f yaml_file($self->id);
 }
 
 sub flush {
     my $self = shift;
-    open(my $sessionfh, '>', yaml_file($self->id)) or die $!;
+    my $sessionfh = open_file('>', yaml_file($self->id));
     print {$sessionfh} YAML::Dump($self);
     close $sessionfh;
     return $self;
