@@ -11,13 +11,18 @@ use base 'Dancer::Engine';
 # return: a string of $template's content processed with $tokens
 sub render { confess "render not implemented" }
 
-sub default_tmpl_ext {"tt"}
+sub default_tmpl_ext { "tt" }
+
+sub _template_name {
+    my ( $self, $view ) = @_;
+    my $def_tmpl_ext = $self->config->{extension} || $self->default_tmpl_ext();
+    $view .= ".$def_tmpl_ext" if $view !~ /\.${def_tmpl_ext}$/;
+}
 
 sub view {
     my ($self, $view) = @_;
 
-    my $def_tmpl_ext = $self->default_tmpl_ext();
-    $view .= ".$def_tmpl_ext" if $view !~ /\.${def_tmpl_ext}$/;
+    $view = $self->_template_name($view);
 
     my $app = Dancer::App->current;
     return path($app->setting('views'), $view);
@@ -27,8 +32,7 @@ sub layout {
     my ($self, $layout, $tokens, $content) = @_;
 
     my $app          = Dancer::App->current;
-    my $def_tmpl_ext = $self->default_tmpl_ext();
-    $layout .= ".$def_tmpl_ext" if $layout !~ /\.${def_tmpl_ext}$/;
+    $layout = $self->_template_name($layout);
     $layout = path($app->setting('views'), 'layouts', $layout);
 
     my $full_content =
@@ -74,6 +78,15 @@ as Dancer will do that.
 Note 2: for backwords compatibility abstract class returns "tt" instead of throwing
 an exception 'method not implemented'.
 
+User would be able to change the default extension using the
+C<<extension>> configuration variable on the template
+configuration. For example, for the default (C<Simple>) engine:
+
+     template: "simple"
+     engines:
+       simple:
+         extension: 'tmpl'
+
 =item B<view($view)>
 
 The default behavior of this method is to return the path of the given view.
